KANARY Viewer

Priority View

## Open Alerts

Only FIRING, ACKED, and SILENCED alerts are shown here.
Full Inventory

## All Alerts

Rule | State | Severity | Acked By | Silences | Outputs | Message |
--- | --- | --- | --- | --- | --- | --- | ---

Alert Detail

## Alert

Back to Alerts
Select an alert from Dashboard or Alerts.

### Acknowledge

Operator Reason

### Silence For

Operator Minutes Reason

### Silence Window

Operator Start End Reason

### History

### Payload

Runtime Health

## Source Plugins

Source | State | Updated | File | Last Error |
--- | --- | --- | --- | --- | ---

Runtime Health

## Rule Plugins

Rule | State | Updated | File | Last Error |
--- | --- | --- | --- | --- | ---

Delivery Layer

## Output Plugins

Plugin | State | Runs | Updated | Last Failure | File | Last Error |
--- | --- | --- | --- | --- | --- | --- | ---

Operator Scheduling

## Silences

Hide cancelled and expired

ID | Status | Window | Targets | By | Reason |
--- | --- | --- | --- | --- | --- | ---

Planning

## Register Silence By Pattern Or Tag

### Silence For

Operator Rule Pattern Tags Minutes Optional Start Reason

### Silence Window

Operator Rule Pattern Tags Start End Reason
Runtime Control

## Management

Operational note

All write operations in this viewer also exist in `kanaryctl`. Use the CLI for automation, the viewer for fast triage and dashboard monitoring.

Read Only Source

## Plugin Source